package org.herac.tuxguitar.android.browser.filesystem;

import org.herac.tuxguitar.android.browser.model.TGBrowserFactorySettingsHandler;

public interface TGFsBrowserSettingsFactory {
	
	void createSettings(TGBrowserFactorySettingsHandler handler);
}
